@@ -1,4 +1,5 @@
 ((nil . ((fill-column . 90)
          ;; force reinstall of whitespace font-lock customization
-         (eval . (whitespace-color-on))))
+         (eval . (if (functionp 'whitespace-color-on)
+		     (whitespace-color-on)))))
  (c++-mode . ((eval . (c-set-style "stroustrup")))))
